==> haskell-xml-conduit-1.8.0-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.8.0
id: xml-conduit-1.8.0-FJltbUPSWixDMnrfARxCEh
key: xml-conduit-1.8.0-FJltbUPSWixDMnrfARxCEh
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
abi: 6d211c383cd1f227aab8bf60237f1a38
exposed: True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
hidden-modules: Text.XML.Stream.Token
import-dirs: /usr/lib/ghc-8.4.3/site-local/xml-conduit-1.8.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/xml-conduit-1.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/xml-conduit-1.8.0
hs-libraries: HSxml-conduit-1.8.0-FJltbUPSWixDMnrfARxCEh
depends:
    base-4.11.1.0 conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
    conduit-extra-1.3.0-87goSKbnlY0JxObgNuqdId
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be bytestring-0.10.8.2
    text-1.2.3.0 containers-0.5.11.0
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ transformers-0.5.5.0
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
    blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq deepseq-1.4.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
             conduit-extra-1.3.0-87goSKbnlY0JxObgNuqdId=15e73479198449396f6e4efa6ea25606
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=543959199634991899560acc46edfd26
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI=1f75827c7503f69e21680c4f5fdd5ce1
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.8.0-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.8.0
id: xml-conduit-1.8.0-GagNdeJ1PPA64O4ZZjZLhG
key: xml-conduit-1.8.0-GagNdeJ1PPA64O4ZZjZLhG
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
abi: 4b15a73ad6920f20ed76816962e99c5e
exposed: True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
hidden-modules: Text.XML.Stream.Token
import-dirs: /usr/lib/ghc-8.4.3/site-local/xml-conduit-1.8.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/xml-conduit-1.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/xml-conduit-1.8.0
hs-libraries: HSxml-conduit-1.8.0-GagNdeJ1PPA64O4ZZjZLhG
depends:
    base-4.11.1.0 conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
    conduit-extra-1.3.0-GaxULXhX2UP3bPKmBvOmT
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be bytestring-0.10.8.2
    text-1.2.3.0 containers-0.5.11.0
    xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ transformers-0.5.5.0
    data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug
    blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq deepseq-1.4.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
             conduit-extra-1.3.0-GaxULXhX2UP3bPKmBvOmT=49651e9ab9985fbad79d2cfea10c977e
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             xml-types-0.3.6-FWN9dD9K4Pf2M2rvMuT5Tt=543959199634991899560acc46edfd26
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             monad-control-1.0.2.3-K5eUA1ylIOoGSY0Oxd45CI=1f75827c7503f69e21680c4f5fdd5ce1
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
